@@ -1,18 +1,7 @@
-/**
- * Copyright (c) Istituto Nazionale di Fisica Nucleare, 2006-2014.
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- *
- *     http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
+// SPDX-FileCopyrightText: 2006 Istituto Nazionale di Fisica Nucleare
+//
+// SPDX-License-Identifier: Apache-2.0
+
 package org.italiangrid.voms.clients.impl;
 
 import static org.italiangrid.voms.request.impl.FakeVOMSACServiceProperties.FAKE;
@@ -226,7 +215,8 @@ public class DefaultVOMSProxyInitBehaviour implements ProxyInitStrategy {
         commandsParser.parseCommands(params.getVomsCommands());
 
     for (String voOrAlias : vomsCommandsMap.keySet()) {
-      if (sis.getVOMSServerInfo(voOrAlias).isEmpty()) {
+      if (sis.getVOMSServerInfo(voOrAlias)
+        .isEmpty()) {
 
         String msg = String.format(
             "VOMS server for VO %s is not known! " + "Check your vomses configuration.", voOrAlias);
@@ -239,7 +229,8 @@ public class DefaultVOMSProxyInitBehaviour implements ProxyInitStrategy {
 
     VOMSServerInfoStore sis = null;
 
-    if (params.getVomsCommands() != null && !params.getVomsCommands().isEmpty()) {
+    if (params.getVomsCommands() != null && !params.getVomsCommands()
+      .isEmpty()) {
       sis = new DefaultVOMSServerInfoStore.Builder()
         .lookupStrategy(getVOMSESLookupStrategyFromParams(params))
         .storeListener(serverInfoStoreListener)
@@ -317,7 +308,8 @@ public class DefaultVOMSProxyInitBehaviour implements ProxyInitStrategy {
     return vomsValidator;
   }
 
-  private void verifyACs(ProxyInitParams params, List<AttributeCertificate> acs) {
+  private void verifyACs(ProxyInitParams params,
+    List<AttributeCertificate> acs) {
 
     VOMSACValidator acValidator = initVOMSValidator(params);
     acValidator.validateACs(acs);
@@ -380,7 +372,8 @@ public class DefaultVOMSProxyInitBehaviour implements ProxyInitStrategy {
       ProxyChainInfo ci;
       try {
         ci = new ProxyChainInfo(issuingCredential.getCertificateChain());
-        if (ci.getProxyType().equals(ProxyChainType.MIXED))
+        if (ci.getProxyType()
+          .equals(ProxyChainType.MIXED))
           throw new VOMSError(
               "Cannot generate a proxy certificate starting from a mixed type proxy chain.");
 
@@ -480,7 +473,8 @@ public class DefaultVOMSProxyInitBehaviour implements ProxyInitStrategy {
 
   protected List<String> sortFQANsIfRequested(ProxyInitParams params, List<String> unsortedFQANs) {
 
-    if (params.getFqanOrder() != null && !params.getFqanOrder().isEmpty()) {
+    if (params.getFqanOrder() != null && !params.getFqanOrder()
+      .isEmpty()) {
 
       Set<String> fqans = new LinkedHashSet<String>();
       for (String fqan : params.getFqanOrder()) {
